import React from "react";
import { useQuery } from "@tanstack/react-query";
import { Link } from "wouter";
import { services as fallbackServices } from "@/constants/data";
import { useTheme } from "@/contexts/ThemeContext";
// Still using the fullstack logo design as requested
const darkLogoPath = "/fullstack-logo-dark.webp";
const lightLogoPath = "/fullstack-logo-light.webp";
import { Service } from "@shared/schema";

const Footer: React.FC = () => {
  const { theme } = useTheme();

  // Fetch all services
  const { data: apiServices = [] } = useQuery({
    queryKey: ["/api/services"],
    // Fall back to hardcoded data if the API call fails or returns empty
    select: (data: Service[] | unknown) => {
      if (Array.isArray(data) && data.length > 0) {
        return data as Service[];
      }
      return fallbackServices;
    },
  });

  return (
    <footer className="bg-dark-300 pt-16 pb-6">
      <div className="container mx-auto px-4">
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8 mb-12">
          <div>
            <Link href="/" className="inline-block mb-6 flex items-center">
              <img
                src={theme === "dark" ? darkLogoPath : lightLogoPath}
                alt="Vetle Haakestad Logo"
                className="h-12 mr-3"
              />
              <span className="text-2xl font-tech font-bold text-white">
                <span className="text-primary">Vetle </span>
                <span className="text-foreground">Haakestad</span>
              </span>
            </Link>
            <p className="text-gray-400 mb-6">
              En faglig sterk prosjektingeniør i automasjon med over 10 års
              branseerfaring, spesialisert i programmering, idriftsettelse og
              utvikling av komplekse automasjonsanlegg og AI-baserte løsninger.
              Brenner for kontinuerlig utvikling og er dypt engasjert i å levere
              høykvalitetsløsninger.
            </p>
            <div className="flex gap-4">
              <a
                href="https://www.linkedin.com/in/vetle-haakestad-322133201/"
                target="_blank"
                rel="noopener noreferrer"
                className="w-10 h-10 rounded-full bg-dark-400 flex items-center justify-center text-gray-300 hover:bg-primary hover:text-white transition-all"
                aria-label="LinkedIn"
              >
                <i className="fab fa-linkedin-in"></i>
              </a>
            </div>
          </div>

          <div>
            <h4 className="text-lg font-bold mb-6 font-sans">Kompetanse</h4>
            <ul className="space-y-3">
              <li>
                <Link
                  href="/kompetanse"
                  className="text-gray-400 hover:text-primary transition-colors"
                >
                  Se all min kompetanse
                </Link>
              </li>
              {Array.isArray(apiServices) && apiServices.map((service: any) => (
                <li key={service.id}>
                  <Link
                    href="/kompetanse"
                    className="text-gray-400 hover:text-primary transition-colors"
                  >
                    {service.title}
                  </Link>
                </li>
              ))}
            </ul>
          </div>

          <div>
            <h4 className="text-lg font-bold mb-6 font-sans">Lenker</h4>
            <ul className="space-y-3">
              <li>
                <Link
                  href="/"
                  className="text-gray-400 hover:text-primary transition-colors"
                >
                  Hjem
                </Link>
              </li>
              <li>
                <Link
                  href="/prosjekter"
                  className="text-gray-400 hover:text-primary transition-colors"
                >
                  Prosjekter
                </Link>
              </li>
              <li>
                <Link
                  href="/kompetanse"
                  className="text-gray-400 hover:text-primary transition-colors"
                >
                  Kompetanse
                </Link>
              </li>
              <li>
                <Link
                  href="/om-oss"
                  className="text-gray-400 hover:text-primary transition-colors"
                >
                  Om meg
                </Link>
              </li>
              <li>
                <Link
                  href="/blogg"
                  className="text-gray-400 hover:text-primary transition-colors"
                >
                  Blogg
                </Link>
              </li>
              <li>
                <Link
                  href="/kontakt"
                  className="text-gray-400 hover:text-primary transition-colors"
                >
                  Kontakt
                </Link>
              </li>
            </ul>
          </div>
        </div>

        <div className="border-t border-dark-400 pt-6">
          <div className="flex flex-col md:flex-row justify-between items-center">
            <p className="text-gray-500 text-sm mb-4 md:mb-0">
              &copy; {new Date().getFullYear()} vetlehaakestad.com. Alle
              rettigheter reservert.
            </p>
            <div className="flex gap-6">
              <Link
                href="/personvernerklaering"
                className="text-gray-500 hover:text-primary text-sm transition-colors"
              >
                Personvernerklæring
              </Link>
              <Link
                href="/vilkar-for-bruk"
                className="text-gray-500 hover:text-primary text-sm transition-colors"
              >
                Vilkår for bruk
              </Link>
              <Link
                href="/cookies"
                className="text-gray-500 hover:text-primary text-sm transition-colors"
              >
                Cookies
              </Link>
            </div>
          </div>
        </div>
      </div>
    </footer>
  );
};

export default Footer;
